@@ -485,13 +485,15 @@ class log_monitor_manager {
             return;
         }
         
-        // ProFTPD access.log format (IP-only format after config fix):
-        // Failed auth: IP_ADDRESS UNKNOWN - [timestamp] "PASS (hidden)" 530 -
-        // Failed REIN: IP_ADDRESS UNKNOWN - [timestamp] "REIN" 502 -
-        // Status codes: 530 = authentication failed, 502 = command error (potential scanning)
+        // ProFTPD access.log format:
+        // IP_ADDRESS USERNAME - [timestamp] "COMMAND" STATUS_CODE -
+        // Common failure status codes:
+        // 530 = authentication failed (PASS command)
+        // 550 = permission denied (USER command, file access)
+        // 502 = command not implemented (potential scanning)
         
-        // Pattern to match failed login attempts (530) and excessive REIN errors (502)
-        if (preg_match('/^(\d+\.\d+\.\d+\.\d+)\s+(\S+)\s+-\s+\[.*?\]\s+"(?:PASS \(hidden\)|REIN)"\s+(530|502)/', $line, $matches)) {
+        // Pattern to match various failed FTP attempts
+        if (preg_match('/^(\d+\.\d+\.\d+\.\d+)\s+(\S+)\s+-\s+\[.*?\]\s+"([^"]+)"\s+(530|550|502)/', $line, $matches)) {
             $ip = $matches[1];
             $username_field = $matches[2];
             $status_code = $matches[3];
@@ -645,7 +647,7 @@ class log_monitor_manager {
      * $result = $monitor->block_service_ip('ssh', '203.0.113.45', 'Too many failed attempts', 15);
      * if ($result) echo "IP blocked successfully";
      */
-    public function block_service_ip($service, $ip, $reason = 'Manual block', $failed_attempts = 0) {
+    public function block_service_ip($service, $ip, $reason = 'Manual block', $failed_attempts = 0, $permanent = false) {
         // Check if IP is whitelisted
         require_once('/docker/whp/web/libs/security_manager.php');
         $sec_manager = new security_manager();
@@ -686,11 +688,14 @@ class log_monitor_manager {
             $firewall_rule_added = $this->add_service_blocks($ip) ? 1 : 0;
         }
         
+        // Calculate unblock time - 0 means permanent block
+        $unblock_time = $permanent ? 0 : (time() + $block_duration);
+        
         $stmt = $this->db->prepare('INSERT OR REPLACE INTO service_blocked_ips (service_type, ip_address, block_time, unblock_time, reason, failed_attempts, firewall_rule_added) VALUES (?, ?, ?, ?, ?, ?, ?)');
         $stmt->bindValue(1, $service, SQLITE3_TEXT);
         $stmt->bindValue(2, $ip, SQLITE3_TEXT);
         $stmt->bindValue(3, time(), SQLITE3_INTEGER);
-        $stmt->bindValue(4, time() + $block_duration, SQLITE3_INTEGER);
+        $stmt->bindValue(4, $unblock_time, SQLITE3_INTEGER);
         $stmt->bindValue(5, $reason, SQLITE3_TEXT);
         $stmt->bindValue(6, $failed_attempts, SQLITE3_INTEGER);
         $stmt->bindValue(7, $firewall_rule_added, SQLITE3_INTEGER);
