@@ -782,7 +782,11 @@ if (!empty($service_blocked_ips)): ?>
                                     $service_display = 'UNKNOWN';
                                     $badge_class = 'secondary';
                                     
+                                    // Get the reason first as it's most reliable for determining source
+                                    $reason = $blocked['reason'] ?? '';
+                                    
                                     // Check the actual service field if available
+                                    $blocking_service = '';
                                     if (!empty($blocked['service'])) {
                                         $blocking_service = $blocked['service'];
                                     } elseif (!empty($blocked['blocking_service'])) {
@@ -791,37 +795,46 @@ if (!empty($service_blocked_ips)): ?>
                                         $blocking_service = $blocked['service_type'];
                                     }
                                     
-                                    // Also check the reason for clues
-                                    $reason = $blocked['reason'] ?? '';
-                                    
-                                    // Determine display based on service or reason
-                                    if ($blocking_service == 'ssh' || stripos($reason, 'ssh') !== false) {
-                                        $badge_class = 'primary';
-                                        $service_display = 'SSH';
-                                    } elseif ($blocking_service == 'ftp' || stripos($reason, 'ftp') !== false) {
-                                        $badge_class = 'info';
-                                        $service_display = 'FTP';
-                                    } elseif ($blocking_service == 'whp' || stripos($reason, 'whp') !== false || stripos($reason, 'failed login') !== false) {
-                                        $badge_class = 'success';
-                                        $service_display = 'WHP';
-                                    } elseif ($blocking_service == 'haproxy' || stripos($reason, 'haproxy') !== false) {
-                                        $badge_class = 'danger';
-                                        $service_display = 'HAProxy';
-                                    } elseif (stripos($reason, 'manual') !== false) {
+                                    // Determine display based on reason first, then service
+                                    // Priority: Manual blocks, then specific service mentions in reason, then service field
+                                    if (stripos($reason, 'manual') !== false) {
                                         $badge_class = 'warning';
                                         $service_display = 'MANUAL';
+                                    } elseif (stripos($reason, 'failed login') !== false || stripos($reason, 'too many failed login attempts') !== false) {
+                                        $badge_class = 'success';
+                                        $service_display = 'WHP';
+                                    } elseif (stripos($reason, 'failed ssh') !== false || (stripos($reason, 'ssh') !== false && stripos($reason, 'failed') !== false)) {
+                                        $badge_class = 'primary';
+                                        $service_display = 'SSH';
+                                    } elseif (stripos($reason, 'failed ftp') !== false || (stripos($reason, 'ftp') !== false && stripos($reason, 'failed') !== false)) {
+                                        $badge_class = 'info';
+                                        $service_display = 'FTP';
+                                    } elseif (stripos($reason, 'haproxy') !== false) {
+                                        $badge_class = 'danger';
+                                        $service_display = 'HAProxy';
                                     } elseif ($blocking_service == 'security_manager') {
-                                        // For security_manager, check if it's manual or WHP
-                                        if (stripos($reason, 'manual') !== false) {
-                                            $badge_class = 'warning';
-                                            $service_display = 'MANUAL';
-                                        } else {
-                                            $badge_class = 'success';
-                                            $service_display = 'WHP';
-                                        }
+                                        // For security_manager with no specific reason, default to WHP
+                                        $badge_class = 'success';
+                                        $service_display = 'WHP';
+                                    } elseif ($blocking_service == 'ssh') {
+                                        $badge_class = 'primary';
+                                        $service_display = 'SSH';
+                                    } elseif ($blocking_service == 'ftp') {
+                                        $badge_class = 'info';
+                                        $service_display = 'FTP';
+                                    } elseif ($blocking_service == 'whp') {
+                                        $badge_class = 'success';
+                                        $service_display = 'WHP';
+                                    } elseif ($blocking_service == 'haproxy') {
+                                        $badge_class = 'danger';
+                                        $service_display = 'HAProxy';
                                     } elseif (!empty($blocking_service)) {
                                         $badge_class = 'secondary';
                                         $service_display = strtoupper($blocking_service);
+                                    } else {
+                                        // Default fallback
+                                        $badge_class = 'secondary';
+                                        $service_display = 'UNKNOWN';
                                     }
                                     ?>
                                     <span class="badge bg-<?php echo $badge_class; ?>"><?php echo $service_display; ?></span>
